@@ -2,7 +2,7 @@
 
 /**
   * SquirrelMail Login Manager Plugin
-  * Copyright (C) 2003-2006 Paul Lesneiwski <paul@squirrelmail.org>
+  * Copyright (C) 2003-2007 Paul Lesneiwski <paul@squirrelmail.org>
   * This program is licensed under GPL. See COPYING for details
   *
   * @package plugins
@@ -415,10 +415,12 @@ function overrideSmConfig($args, $user='', $hostname='', $hostname_stripped='',
 
   // override the org_logo and other stuff if we find a match
   //
-  // only need to do this stuff when first logging in
+  // only need to do this stuff when first logging in or on signout
+  // page when session was possibly lost
   //
   if (!$checkServiceLevel || strpos($PHP_SELF, 'redirect.php') !== FALSE
-   || strpos($PHP_SELF, 'login.php') !== FALSE)
+   || strpos($PHP_SELF, 'login.php') !== FALSE 
+   || strpos($PHP_SELF, 'signout.php') !== FALSE)
 //
 // NOTE: the following line will solve PHP 4.3 problems when using
 //       the session_recall patch, however it will also unfortunately
@@ -445,6 +447,9 @@ function overrideSmConfig($args, $user='', $hostname='', $hostname_stripped='',
       }
 
 
+      $already_enabled = array();
+
+
       foreach ($virtualDomains[$virtualDomain] as $setting => $value)
       {
 
@@ -474,10 +479,12 @@ function overrideSmConfig($args, $user='', $hostname='', $hostname_stripped='',
            }
            else
            {
+              $already_enabled = $value;
               foreach ($value as $pluginName)
               {
-                 $plugins[] = $pluginName;
-                 use_plugin($pluginName);
+                 // function is found in Compatibility plugin v2.0.5+
+                 //
+                 add_plugin($pluginName, $args);
               }
            }
            continue;
@@ -494,16 +501,41 @@ function overrideSmConfig($args, $user='', $hostname='', $hostname_stripped='',
            }
            else
            {
-              foreach ($value as $pluginName)
+              // disable ALL plugins?
+              //
+              if (in_array('*', $value))
               {
-                 $pluginKey = array_search($pluginName, $plugins);
-                 if (!is_null($pluginKey) && $pluginKey !== FALSE)
+                 $reenable_vlogin = FALSE;
+                 $reenable_multilogin = FALSE;
+                 if (in_array('vlogin', $plugins))
+                    $reenable_vlogin = TRUE;
+                 if (in_array('multilogin', $plugins))
+                    $reenable_multilogin = TRUE;
+
+                 $plugins = array();
+                 $squirrelmail_plugin_hooks = array();
+
+                 // if we had already enabled some plugins,
+                 // reenable them again
+                 //
+                 foreach ($already_enabled as $pluginName)
+                    add_plugin($pluginName, $args, TRUE);
+
+                 if ($reenable_multilogin)
+                    add_plugin('multilogin', $args, TRUE);
+                 if ($reenable_vlogin)
+                    add_plugin('vlogin', $args, TRUE);
+              }
+
+              // no, just disable some plugins...
+              //
+              else
+              {
+                 foreach ($value as $pluginName)
                  {
-                    unset($plugins[$pluginKey]);
-                    foreach (array_keys($squirrelmail_plugin_hooks) as $hookName)
-                    {
-                       unset($squirrelmail_plugin_hooks[$hookName][$pluginName]);
-                    }
+                    // function is found in Compatibility plugin v2.0.5+
+                    //
+                    remove_plugin($pluginName);
                  }
               }
            }
@@ -1718,4 +1750,3 @@ function vlogin_get_database_connection()
 
 
 
-?>
