@@ -2,7 +2,7 @@
 
 /**
   * SquirrelMail Login Manager Plugin
-  * Copyright (c) 2003-2006 Paul Lesneiwski <paul@squirrelmail.org>
+  * Copyright (c) 2003-2007 Paul Lesneiwski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -17,50 +17,50 @@
   */
 function squirrelmail_plugin_init_vlogin() {
 
-  global $squirrelmail_plugin_hooks;
+   global $squirrelmail_plugin_hooks;
 
 
-  $squirrelmail_plugin_hooks['login_before']['vlogin']               = 'vlogin_domain';
+   $squirrelmail_plugin_hooks['login_before']['vlogin']               = 'vlogin_domain';
 
-  $squirrelmail_plugin_hooks['login_verified']['vlogin']             = 'vlogin_save_original';
+   $squirrelmail_plugin_hooks['login_verified']['vlogin']             = 'vlogin_save_original';
+   $squirrelmail_plugin_hooks['logout']['vlogin']                     = 'vlogin_overrideSmConfig';
 
-  $squirrelmail_plugin_hooks['optpage_loadhook_display']['vlogin']   = 'vlogin_display_options';
-  $squirrelmail_plugin_hooks['optpage_loadhook_personal']['vlogin']  = 'vlogin_display_options';
-  $squirrelmail_plugin_hooks['optpage_loadhook_folder']['vlogin']    = 'vlogin_display_options';
-  $squirrelmail_plugin_hooks['optpage_loadhook_highlight']['vlogin'] = 'vlogin_display_options';
-  $squirrelmail_plugin_hooks['optpage_loadhook_order']['vlogin']     = 'vlogin_display_options';
+   $squirrelmail_plugin_hooks['optpage_loadhook_display']['vlogin']   = 'vlogin_display_options';
+   $squirrelmail_plugin_hooks['optpage_loadhook_personal']['vlogin']  = 'vlogin_display_options';
+   $squirrelmail_plugin_hooks['optpage_loadhook_folder']['vlogin']    = 'vlogin_display_options';
+   $squirrelmail_plugin_hooks['optpage_loadhook_highlight']['vlogin'] = 'vlogin_display_options';
+   $squirrelmail_plugin_hooks['optpage_loadhook_order']['vlogin']     = 'vlogin_display_options';
 
 
-  // not technically necessary when $useSessionBased is turned off, but...
-  // as of SM 1.5.2 no dynamic code is run in this function (this function
-  // is parsed at config time and never actually run by SM at all)
-  //
-  $squirrelmail_plugin_hooks['login_cookie']['vlogin'] = 'vlogin_overrideSmConfig';
-  $squirrelmail_plugin_hooks['webmail_top']['vlogin'] = 'vlogin_overrideSmConfig';
+   // not technically necessary when $useSessionBased is turned off, but...
+   // as of SM 1.5.2 no dynamic code is run in this function (this function
+   // is parsed at config time and never actually run by SM at all)
+   //
+   $squirrelmail_plugin_hooks['login_cookie']['vlogin'] = 'vlogin_overrideSmConfig';
+   $squirrelmail_plugin_hooks['webmail_top']['vlogin'] = 'vlogin_overrideSmConfig';
 
 
-  // In 1.5.2, just register the Multilogin plugin on the config 
-  // override hook, no need to activate multilogin or patch the 
-  // source code.  Whew.
-  //
-  $squirrelmail_plugin_hooks['config_override']['multilogin'] = 'multilogin_sqoverride_config';
+   // In 1.5.2, just register the Multilogin plugin on the config 
+   // override hook, no need to activate multilogin or patch the 
+   // source code.  Whew.
+   //
+   $squirrelmail_plugin_hooks['config_override']['multilogin'] = 'multilogin_sqoverride_config';
 
 
-  // this code only works pre 1.5.2 and is deprecated; users should
-  // migrate to $useSessionBased anyway... 1.5.2 no longer requires 
-  // patching to do so
-  //
-  include_once(SM_PATH . 'plugins/vlogin/functions.php');
-  load_vlogin_config();
-  global $useSessionBased;
-  if (!$useSessionBased)
-  {
+   // this code only works pre 1.5.2 and is deprecated; users should
+   // migrate to $useSessionBased anyway... 1.5.2 no longer requires 
+   // patching to do so
+   //
+   include_once(SM_PATH . 'plugins/vlogin/functions.php');
+   load_vlogin_config();
+   global $useSessionBased;
+   if (!$useSessionBased)
+   {
 
      include_once(SM_PATH . 'plugins/vlogin/functions.php');
      overrideSmConfig(array('squirrelmail_plugin_init_vlogin')); // dummy hook name
 
-  }
-
+   }
 
 }
 
@@ -81,9 +81,12 @@ function vlogin_info()
 
    return array(
                  'english_name' => 'Login Manager',
-                 'version' => '3.9.0',
+                 'version' => '3.9.1',
                  'required_sm_version' => '1.2.7',
                  'requires_configuration' => 0,
+                 'required_plugins' => array(
+                                               'compatibility' => '2.0.5',
+                                            ),
                  'requires_source_patch' => 0,
                  'required_php_version' => '4.0.6',
                  'summary' => 'Helps manage and manipulate usernames given at login time, and allows the use of different SquirrelMail settings (such as login page image, or IMAP server) for each domain, each user, or each user group',
